/***************************************************************************
 *            props.h
 *
 *  Tue Aug  2 20:59:10 2005
 *  Copyright  2005  Fabio Marzocca
 *  Email
 ****************************************************************************/

#ifndef BAOBAB_PROPS_H
#define BAOBAB_PROPS_H

/* pros model columns */
enum
{
  COL_CHECK,
  COL_DEVICE,
  COL_MOUNT,
  COL_CHECK_INCONSISTENT,
  TOT_COLUMNS
};


	
void  props_notify (GConfClient *client,
                    guint cnxn_id,
                    GConfEntry *entry,
                    gpointer user_data);	
	
void create_props(void);
	

#endif /* _PROPS_H */
